# ifndef yyReductionComm
# define yyReductionComm

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 15 "ReductionComm.puma" */


#include "VarDescriptor.h"



extern void (* ReductionComm_Exit) ARGS ((void));

extern void ReductionCommunication ARGS ((tTree body));

extern void BeginReductionComm ARGS ((void));
extern void CloseReductionComm ARGS ((void));

# endif
